(define-module (ui sshd ajax)
  :use-module (alterator ajax)
  :use-module (alterator algo)
  :use-module (alterator str)
  :use-module (alterator woo)
  :use-module (alterator effect)
  :export (init))

(define (ui-init)
    (form-update-value-list
      (woo-read-first "/sshd/state" 
        'language (form-value "language")))
    (form-update-visibility "hidable_main" #t)
    (form-update-visibility "ss_btn" #t)
    (form-update-visibility "toKeys_btn" #t)
    (form-update-enum "loginmode" 
      (woo-list "/sshd/loginmodes" 
       'language (form-value "language")))
    (form-update-enum "wheelmode" 
      (woo-list "/sshd/passwdauth" 
       'language (form-value "language")))
    (form-update-enum "addr_family" 
      (woo-list "/sshd/addrfamily" 
       'language (form-value "language")))
    (form-update-enum "authmode" 
      (woo-list "/sshd/passwdauth" 
       'language (form-value "language")))
)

(define (change_daemon)
    (catch/message
	(lambda() (woo-write "/sshd/daemon" 'status (form-value "daemon"))))
    (form-update-value-list
       (woo-read-first "/sshd/state" 
      'language (form-value "language"))))

(define (restart_daemon)
    (catch/message
    (lambda() (woo-write "/sshd/reload")))
    (form-update-value-list
      '("cur_status" ) (woo-read-first "/sshd/state" 
	    'language (form-value "language"))))

(define (update_settings)
    (catch/message
      (lambda() 
	(apply woo-write "/sshd/settings" (form-value-list))
	    (ui-init)
	    (update-effect)))
    (form-update-visibility "hidable_settings" #f)
    (form-update-visibility "Apply_btn" #f)
    (form-update-visibility "Return_btn" #f)
    (form-update-visibility "hidable_main" #t)
    (form-update-visibility "ss_btn" #t)
    (form-update-visibility "toKeys_btn" #t)
)

(define (change_crontab)
    (catch/message
	(lambda() (woo-write "/sshd/enable_cron" 'cron (form-value "enable_updates"))))
    (form-update-activity "update_period" (form-value "enable_updates"))
)

(define (show_settings)
    (form-update-value-list
       (woo-read-first "/sshd/settings" 
	    'language (form-value "language")))
    (update-effect)
    (form-update-visibility "hidable_settings" #t)
    (form-update-visibility "Apply_btn" #t)
    (form-update-visibility "Return_btn" #t)
    (form-update-visibility "ss_btn" #f)
    (form-update-visibility "toKeys_btn" #f)
    (form-update-visibility "hidable_main" #f)
)

(define (return_settings)
    (form-update-visibility "hidable_settings" #f)
    (form-update-visibility "Apply_btn" #f)
    (form-update-visibility "Return_btn" #f)
    (form-update-visibility "ss_btn" #t)
    (form-update-visibility "toKeys_btn" #t)
    (form-update-visibility "hidable_main" #t)
)

(define (manage_keys)
    (form-replace "/sshd/keys"))

(define (addr_trigger)
    (let ( (type (car (string-cut-repeated (or (form-value "addr_family") "any") #\,))) )
      (cond
       ((string-ci=? type "inet")(form-update-value "use_ipv6address" #f))
       ((string-ci=? type "inet6")(form-update-value "use_ipv4address" #f))))
      (update-effect)
)

(define (init)
    (effect-enable "sshd_ipv4address" "use_ipv4address" #t)
    (effect-enable "sshd_ipv6address" "use_ipv6address" #t)
    (effect-disable "use_ipv6address" "addr_family" "inet")
    (effect-disable "use_ipv4address" "addr_family" "inet6")
    (effect-enable "sshd_port" "use_port" #t)
    (effect-enable "addr_family" "use_family" #t)
    (effect-enable "loginmode" "use_prl" #t)
    (effect-enable "sftp_subsys" "use_sftp" #t)
    (effect-enable "banner_path" "use_banner" #t)
    (effect-enable "allowed_groups" "use_groups" #t)
    (effect-enable "allowed_users" "use_users" #t)
    (effect-enable "authmode" "use_auth" #t)
    (effect-enable "wheelmode" "math_wheel" #t)
    (init-effect)
    (ui-init)
    (form-bind "addr_family" "change" addr_trigger)
    (form-bind "ss_btn" "click" show_settings)
    (form-bind "toKeys_btn" "click" manage_keys)
    (form-bind "daemon" "change" change_daemon)
    (form-bind "reload_btn" "click" restart_daemon)
    (form-bind "Apply_btn" "click" update_settings)
    (form-bind "Return_btn" "click" return_settings)
)
